==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/gl.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "O almacenamento non está dispoñíbel temporalmente",
    "Storage invalid" : "Almacenamento incorrecto",
    "Unknown error" : "Produciuse un erro descoñecido",
    "All files" : "Todos os ficheiros",
    "Recent" : "Recente",
    "File could not be found" : "Non foi posíbel atopar o ficheiro",
    "Home" : "Inicio",
    "Close" : "Pechar",
    "Favorites" : "Favoritos",
    "Could not create folder \"{dir}\"" : "Non foi posíbel crear o cartafol «{dir}»",
    "Upload cancelled." : "Envío cancelado.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Non é posíbel enviar {filename}, xa que ou é un directorio ou ten 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Non hai espazo libre abondo, o seu envío é de {size1} mais só dispón de {size2}",
    "Target folder \"{dir}\" does not exist any more" : "O cartafol de destino «{dir}» xa non existe",
    "Not enough free space" : "Non hai espazo libre abondo",
    "Uploading..." : "Enviando...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
    "Actions" : "Accións",
    "Download" : "Descargar",
    "Rename" : "Renomear",
    "Move" : "Mover",
    "Target folder" : "Cartafol de destino",
    "Delete" : "Eliminar",
    "Disconnect storage" : "Desconectar o almacenamento",
    "Unshare" : "Deixar de compartir",
    "Could not load info for file \"{file}\"" : "Non foi posíbel cargar información para o ficheiro «{file}»",
    "Files" : "Ficheiros",
    "Details" : "Detalles",
    "Select" : "Seleccionar",
    "Pending" : "Pendentes",
    "Unable to determine date" : "Non é posíbel determinar a data",
    "This operation is forbidden" : "Esta operación está prohibida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Este directorio non está dispoñíbel, comprobe os rexistros ou póñase en contacto co administrador",
    "Could not move \"{file}\", target exists" : "Non foi posíbel mover «{file}», o destino xa existe",
    "Could not move \"{file}\"" : "Non foi posíbel mover «{file}»",
    "{newName} already exists" : "Xa existe {newName}",
    "Could not rename \"{fileName}\", it does not exist any more" : "Non foi posíbel renomear «{fileName}», xa non existe",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "O nome «{targetName}» xa se utiliza no cartafol «{dir}». Escolla outro nome.",
    "Could not rename \"{fileName}\"" : "Non foi posíbel renomear «{fileName}»",
    "Could not create file \"{file}\"" : "Non foi posíbel crear o ficheiro «{file}»",
    "Could not create file \"{file}\" because it already exists" : "Non foi posíbel crear o ficheiro «{file}» por mor de que xa existe",
    "Could not create folder \"{dir}\" because it already exists" : "Non foi posíbel crear o cartafol «{dir}» por mor de que xa existe",
    "Error deleting file \"{fileName}\"." : "Produciuse un erro ao eliminar o ficheiro «{fileName}».",
    "No search results in other folders for {tag}{filter}{endtag}" : "Non foi posíbel atopar resultados de busca noutros cartafoles para {tag}{filter}{endtag}",
    "Name" : "Nome",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "_%n folder_::_%n folders_" : ["%n cartafol","%n cartafoles"],
    "_%n file_::_%n files_" : ["%n ficheiro","%n ficheiros"],
    "{dirs} and {files}" : "{dirs} e {files}",
    "_including %n hidden_::_including %n hidden_" : ["incluíndo %n agochado","incluíndo %n agochados"],
    "You don’t have permission to upload or create files here" : "Non ten permisos para enviar ou crear ficheiros aquí.",
    "_Uploading %n file_::_Uploading %n files_" : ["Cargando %n ficheiro","Cargando %n ficheiros"],
    "New" : "Novo",
    "\"{name}\" is an invalid file name." : "«{name}» é un nome incorrecto de ficheiro.",
    "File name cannot be empty." : "O nome de ficheiro non pode estar baleiro",
    "\"{name}\" is not an allowed filetype" : "«{name}» non é un tipo de ficheiro permitido",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "O espazo de almacenamento de {owner} está cheo, non é posíbel actualizar ou sincronizar máis os ficheiros!",
    "Your storage is full, files can not be updated or synced anymore!" : "O seu espazo de almacenamento está cheo, non é posíbel actualizar ou sincronizar máis os ficheiros!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "O espazo de almacenamento de {owner} está case cheo ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "O seu espazo de almacenamento está case cheo ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["coincidente con «{filter}»","coincidentes con «{filter}»"],
    "View in folder" : "Ver no cartafol",
    "Copied!" : "Copiado!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Copiar a ligazón directa (só funciona para usuarios que teñen acceso a este ficheiro/cartafol)",
    "Path" : "Ruta",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Marcado como favorito",
    "Favorite" : "Favorito",
    "New folder" : "Novo cartafol",
    "Upload file" : "Enviar ficheiro",
    "An error occurred while trying to update the tags" : "Produciuse un erro ao tentar actualizar as etiquetas",
    "Added to favorites" : "Engadido a favoritos",
    "Removed from favorites" : "Retirado de favoritos",
    "You added {file} to your favorites" : "Engadiu {file} aos seus favoritos",
    "You removed {file} from your favorites" : "Retirou {file} dos seus favoritos",
    "File changes" : "Cambios do ficheiro",
    "Created by {user}" : "Creado por {user}",
    "Changed by {user}" : "Cambiado por {user}",
    "Deleted by {user}" : "Eliminado por {user}",
    "Restored by {user}" : "Restaurado por {user}",
    "Renamed by {user}" : "Renomeado por {user}",
    "Moved by {user}" : "Movido por {user}",
    "\"remote user\"" : "«usuario remoto»",
    "You created {file}" : "{file} foi creado por vostede",
    "{user} created {file}" : "{user} creou {file}",
    "{file} was created in a public folder" : "{file}  foi creado nun cartafol público",
    "You changed {file}" : "{file} foi cambiado por vostede",
    "{user} changed {file}" : "{user} cambiou {file}",
    "You deleted {file}" : "{file} foi eliminado por vostede",
    "{user} deleted {file}" : "{user} eliminou {file}",
    "You restored {file}" : "{file} foi restaurado por vostede",
    "{user} restored {file}" : "{user} restaurou {file}",
    "You renamed {oldfile} to {newfile}" : "Vostede renomeou {oldfile} como {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} renomeou {oldfile} como {newfile}",
    "You moved {oldfile} to {newfile}" : "Vostede moveu {oldfile} para {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} moveu {oldfile} para {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Engadiuse ou retirouse un ficheiro dos seus <strong>favoritos</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "<strong>Cambiouse</strong> ou <strong>renomeouse</strong> un ficheiro ou cartafol",
    "A new file or folder has been <strong>created</strong>" : "<strong>Creouse</strong> un novo ficheiro ou cartafol",
    "A new file or folder has been <strong>deleted</strong>" : "<strong>Creouse</strong> un novo ficheiro ou cartafol",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limita as notificacións sobre a creación e modificación dos seus <strong>ficheiros favoritos</strong> <em>(só os fluxos)</em>",
    "A new file or folder has been <strong>restored</strong>" : "<strong>Restaurouse</strong> un ficheiro ou cartafol",
    "Upload (max. %s)" : "Envío (máx. %s)",
    "File handling" : "Manexo de ficheiro",
    "Maximum upload size" : "Tamaño máximo do envío",
    "max. possible: " : "máx. posíbel: ",
    "Save" : "Gardar",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Con PHP-FPM podería levarlle 5 minutos para que se realicen os cambios.",
    "Missing permissions to edit from here." : "Faltan os permisos para poder editar desde aquí.",
    "Settings" : "Axustes",
    "Show hidden files" : "Amosar os ficheiros agochados",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Empregue este enderezo para <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">acceder aos seus ficheiros mediante WebDAV</a>",
    "No files in here" : "Aquí non hai ficheiros",
    "Upload some content or sync with your devices!" : "Envíe algún contido ou sincronice cos seus dispositivos!",
    "No entries found in this folder" : "Non se atoparon entradas neste cartafol",
    "Select all" : "Seleccionar todo",
    "Upload too large" : "Envío grande de máis",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Os ficheiros que tenta enviar exceden do tamaño máximo permitido neste servidor",
    "No favorites yet" : "Aínda non hai favoritos",
    "Files and folders you mark as favorite will show up here" : "Os ficheiros e cartafoles que marque como favoritos amosaranse aquí",
    "Shared with you" : "Compartido con vostede",
    "Shared with others" : "Compartido con outros",
    "Shared by link" : "Compartido por ligazón",
    "Tags" : "Etiquetas",
    "Deleted files" : "Ficheiros eliminados",
    "Text file" : "Ficheiro de texto",
    "New text file.txt" : "Novo ficheiro de texto.txt",
    "_{hours}:{minutes}:{seconds} hour left_::_{hours}:{minutes}:{seconds} hours left_" : ["Resta {hours}:{minutes}:{seconds} hora","Restan {hours}:{minutes}:{seconds} horas"],
    "{hours}:{minutes}h" : "{hours}:{minutes}h",
    "_{minutes}:{seconds} minute left_::_{minutes}:{seconds} minutes left_" : ["Resta {minutes}:{seconds} minuto","Restan {minutes}:{seconds} minutos"],
    "{minutes}:{seconds}m" : "{minutes}:{seconds}m",
    "_{seconds} second left_::_{seconds} seconds left_" : ["Resta {seconds} segundo","Restan {seconds} segundos"],
    "{seconds}s" : "{seconds}s",
    "Any moment now..." : "En calquera momento",
    "Soon..." : "Nun chisco",
    "File upload is in progress. Leaving the page now will cancel the upload." : "O envío do ficheiro está en proceso. Saír agora da páxina cancelará o envío.",
    "Copy local link" : "Copiar a ligazón local",
    "Folder" : "Cartafol",
    "Upload" : "Enviar",
    "No favorites" : "Non hai favoritos"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/gl.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "O almacenamento non está dispoñíbel temporalmente",
    "Storage invalid" : "Almacenamento incorrecto",
    "Unknown error" : "Produciuse un erro descoñecido",
    "All files" : "Todos os ficheiros",
    "Recent" : "Recente",
    "Favorites" : "Favoritos",
    "File could not be found" : "Non foi posíbel atopar o ficheiro",
    "Move or copy" : "Mover ou copiar",
    "Download" : "Descargar",
    "Delete" : "Eliminar",
    "Home" : "Inicio",
    "Close" : "Pechar",
    "Could not create folder \"{dir}\"" : "Non foi posíbel crear o cartafol «{dir}»",
    "This will stop your current uploads." : "Isto deterá os envíos actuais.",
    "Upload cancelled." : "Envío cancelado.",
    "Processing files …" : "Procesando ficheiros…",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Non é posíbel enviar {filename}, xa que ou é un directorio ou ten 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Non hai espazo libre abondo, o seu envío é de {size1} mais só dispón de {size2}",
    "Target folder \"{dir}\" does not exist any more" : "O cartafol de destino «{dir}» xa non existe",
    "Not enough free space" : "Non hai espazo libre abondo",
    "An unknown error has occurred" : "Produciuse un erro descoñecido",
    "Uploading …" : "Enviando…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Non se admite o envío deste elemento",
    "Target folder does not exist any more" : "O cartafol de destino xa non existe",
    "Error when assembling chunks, status code {status}" : "Produciuse un erro ao ensamblar os bloques, código de estado {status}",
    "Actions" : "Accións",
    "Rename" : "Renomear",
    "Copy" : "Copiar",
    "Choose target folder" : "Escoller o cartafol de destino",
    "Open" : "Abrir",
    "Delete file" : "Eliminar ficheiro",
    "Delete folder" : "Eliminar cartafol",
    "Disconnect storage" : "Desconectar o almacenamento",
    "Unshare" : "Deixar de compartir",
    "Could not load info for file \"{file}\"" : "Non foi posíbel cargar información para o ficheiro «{file}»",
    "Files" : "Ficheiros",
    "Details" : "Detalles",
    "Select" : "Seleccionar",
    "Pending" : "Pendentes",
    "Unable to determine date" : "Non é posíbel determinar a data",
    "This operation is forbidden" : "Esta operación está prohibida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Este directorio non está dispoñíbel, comprobe os rexistros ou póñase en contacto co administrador",
    "Could not move \"{file}\", target exists" : "Non foi posíbel mover «{file}», o destino xa existe",
    "Could not move \"{file}\"" : "Non foi posíbel mover «{file}»",
    "copy" : "copiar",
    "Could not copy \"{file}\", target exists" : "Non foi posíbel copiar «{file}», o destino xa existe",
    "Could not copy \"{file}\"" : "Non foi posíbel copiar «{file}",
    "Copied {origin} inside {destination}" : "Copiado {origin} en {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Copiado {origin} e outros {nbfiles} ficheiros en {destination} ",
    "{newName} already exists" : "Xa existe {newName}",
    "Could not rename \"{fileName}\", it does not exist any more" : "Non foi posíbel renomear «{fileName}», xa non existe",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "O nome «{targetName}» xa se utiliza no cartafol «{dir}». Escolla outro nome.",
    "Could not rename \"{fileName}\"" : "Non foi posíbel renomear «{fileName}»",
    "Could not create file \"{file}\"" : "Non foi posíbel crear o ficheiro «{file}»",
    "Could not create file \"{file}\" because it already exists" : "Non foi posíbel crear o ficheiro «{file}» por mor de que xa existe",
    "Could not create folder \"{dir}\" because it already exists" : "Non foi posíbel crear o cartafol «{dir}» por mor de que xa existe",
    "Error deleting file \"{fileName}\"." : "Produciuse un erro ao eliminar o ficheiro «{fileName}».",
    "No search results in other folders for {tag}{filter}{endtag}" : "Non foi posíbel atopar resultados de busca noutros cartafoles para {tag}{filter}{endtag}",
    "Name" : "Nome",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "_%n folder_::_%n folders_" : ["%n cartafol","%n cartafoles"],
    "_%n file_::_%n files_" : ["%n ficheiro","%n ficheiros"],
    "{dirs} and {files}" : "{dirs} e {files}",
    "_including %n hidden_::_including %n hidden_" : ["incluíndo %n agachado","incluíndo %n agochados"],
    "You don’t have permission to upload or create files here" : "Non ten permisos para enviar ou crear ficheiros aquí.",
    "_Uploading %n file_::_Uploading %n files_" : ["Enviando %n ficheiro","Enviando %n ficheiros"],
    "New" : "Novo",
    "Select file range" : "Seleccionar o intervalo de ficheiros ",
    "{used} of {quota} used" : "Usados {used} de {quota}",
    "{used} used" : "{used} usados",
    "\"{name}\" is an invalid file name." : "«{name}» é un nome incorrecto de ficheiro.",
    "File name cannot be empty." : "O nome de ficheiro non pode estar baleiro",
    "\"/\" is not allowed inside a file name." : "«/» non está permitido nun nome de ficheiro",
    "\"{name}\" is not an allowed filetype" : "«{name}» non é un tipo de ficheiro permitido",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "O espazo de almacenamento de {owner} está cheo, non é posíbel actualizar ou sincronizar máis os ficheiros!",
    "Your storage is full, files can not be updated or synced anymore!" : "O seu espazo de almacenamento está cheo, non é posíbel actualizar ou sincronizar máis os ficheiros!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "O espazo de almacenamento de {owner} está case cheo ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "O seu espazo de almacenamento está case cheo ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["coincidente con «{filter}»","coincidentes con «{filter}»"],
    "View in folder" : "Ver no cartafol",
    "Copied!" : "Copiado!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Copiar a ligazón directa (só funciona para usuarios que teñen acceso a este ficheiro/cartafol)",
    "Path" : "Ruta",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Marcado como favorito",
    "Favorite" : "Favorito",
    "You can only favorite a single file or folder at a time" : "Só pode marcar como favorito un único ficheiro ou cartafol por vez",
    "New folder" : "Novo cartafol",
    "Upload file" : "Enviar ficheiro",
    "Not favorited" : "Non marcado como favorito",
    "Remove from favorites" : "Retirar de favoritos",
    "Add to favorites" : "Engadir a favoritos",
    "An error occurred while trying to update the tags" : "Produciuse un erro ao tentar actualizar as etiquetas",
    "Added to favorites" : "Engadido a favoritos",
    "Removed from favorites" : "Retirado de favoritos",
    "You added {file} to your favorites" : "Engadiu {file} aos seus favoritos",
    "You removed {file} from your favorites" : "Retirou {file} dos seus favoritos",
    "File changes" : "Cambios do ficheiro",
    "Created by {user}" : "Creado por {user}",
    "Changed by {user}" : "Cambiado por {user}",
    "Deleted by {user}" : "Eliminado por {user}",
    "Restored by {user}" : "Restaurado por {user}",
    "Renamed by {user}" : "Renomeado por {user}",
    "Moved by {user}" : "Movido por {user}",
    "\"remote user\"" : "«usuario remoto»",
    "You created {file}" : "{file} foi creado por vostede",
    "You created an encrypted file in {file}" : "Vostede creo un ficheiro cifrado en {file}",
    "{user} created {file}" : "{user} creou {file}",
    "{user} created an encrypted file in {file}" : "{user} creou un ficheiro cifrado en {file}",
    "{file} was created in a public folder" : "{file} foi creado nun cartafol público",
    "You changed {file}" : "{file} foi cambiado por vostede",
    "You changed an encrypted file in {file}" : "Vostede cambiou un ficheiro cifrado en {file}",
    "{user} changed {file}" : "{file} foi cambiado por {user}",
    "{user} changed an encrypted file in {file}" : "{user} cambiou un ficheiro cifrado en {file}",
    "You deleted {file}" : "{file} foi eliminado por vostede",
    "You deleted an encrypted file in {file}" : "Vostede eliminou un ficheiro cifrado en {file}",
    "{user} deleted {file}" : "{file} foi eliminado por {user}",
    "{user} deleted an encrypted file in {file}" : "{user} eliminou un ficheiro cifrado en {file}",
    "You restored {file}" : "{file} foi restaurado por vostede",
    "{user} restored {file}" : "{file} foi restaurado por {user}",
    "You renamed {oldfile} to {newfile}" : "Vostede renomeou {oldfile} como {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} renomeou {oldfile} como {newfile}",
    "You moved {oldfile} to {newfile}" : "Vostede moveu {oldfile} para {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} moveu {oldfile} para {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Engadiuse ou retirouse un ficheiro dos seus <strong>favoritos</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "<strong>Cambiouse</strong> ou <strong>renomeouse</strong> un ficheiro ou cartafol",
    "A new file or folder has been <strong>created</strong>" : "<strong>Creouse</strong> un novo ficheiro ou cartafol",
    "A file or folder has been <strong>deleted</strong>" : "<strong>Eliminouse</strong> un ficheiro ou cartafol",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limita as notificacións sobre a creación e modificación dos seus <strong>ficheiros favoritos</strong> <em>(só os fluxos)</em>",
    "A file or folder has been <strong>restored</strong>" : "<strong>Restaurouse</strong> un ficheiro ou cartafol",
    "Unlimited" : "Sen límites",
    "Upload (max. %s)" : "Envío (máx. %s)",
    "File Management" : "Administración de ficheiros",
    "Error while loading the file data" : "Produciuse un erro ao cargar os datos do ficheiro",
    "Unable to change the favourite state of the file" : "Non é posíbel cambiar o estado favorito do ficheiro",
    "%s used" : "%s utilizado",
    "%s%% of %s used" : "%s%% de %s utilizado",
    "%1$s of %2$s used" : "%s de %s utilizado",
    "Settings" : "Axustes",
    "Show hidden files" : "Amosar os ficheiros agochados",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Empregue este enderezo <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">acceder á súa aplicación Ficheiros mediante WebDAV</a>",
    "Toggle grid view" : "Alternar a vista como grella",
    "No files in here" : "Aquí non hai ficheiros",
    "Upload some content or sync with your devices!" : "Envíe algún contido ou sincronice cos seus dispositivos!",
    "No entries found in this folder" : "Non se atoparon entradas neste cartafol",
    "Select all" : "Seleccionar todo",
    "Upload too large" : "Envío grande de máis",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Os ficheiros que tenta enviar exceden do tamaño máximo permitido neste servidor",
    "No favorites yet" : "Aínda non hai favoritos",
    "Files and folders you mark as favorite will show up here" : "Os ficheiros e cartafoles que marque como favoritos amosaranse aquí",
    "Tags" : "Etiquetas",
    "Deleted files" : "Ficheiros eliminados",
    "Shares" : "Comparticións",
    "Shared with others" : "Compartido con outros",
    "Shared with you" : "Compartido con vostede",
    "Shared by link" : "Compartido por ligazón",
    "Deleted shares" : "Recursos compartidos eliminados",
    "Text file" : "Ficheiro de texto",
    "New text file.txt" : "Novo ficheiro de texto.txt",
    "File handling" : "Manexo de ficheiros",
    "Maximum upload size" : "Tamaño máximo do envío",
    "max. possible: " : "máx. posíbel: ",
    "Save" : "Gardar",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Con PHP-FPM podería levarlle 5 minutos para que se realicen os cambios.",
    "Missing permissions to edit from here." : "Faltan os permisos para poder editar dende aquí.",
    "Cancel upload" : "Cancelar o envío",
    "%s of %s used" : "%s de %s utilizado",
    "%1$s%% of %2$s used" : "%1$s%% de %2$s utilizado"
},
"nplurals=2; plural=(n != 1);");
